==> drun-2.0.4.tar.gz: drun-2.0.4/drun/engine/http.py <==
from __future__ import annotations

from typing import Any, Dict, Optional
import httpx

from drun.engine.timing import TimingCollector


class HTTPClient:
    def __init__(self, base_url: Optional[str] = None, timeout: Optional[float] = None, verify: Optional[bool] = None, headers: Optional[Dict[str, str]] = None, enable_http_stat: bool = False) -> None:
        self.base_url = base_url or ""
        self.timeout = timeout
        self.verify = verify
        self.headers = headers or {}
        self.enable_http_stat = enable_http_stat
        
        # 设置 event hooks（如果启用了 http_stat）
        event_hooks = {}
        if self.enable_http_stat:
            self.timing_collector = TimingCollector()
            event_hooks = {
                "request": [self.timing_collector.on_request],
                "response": [self.timing_collector.on_response],
            }
        else:
            self.timing_collector = None
        
        self.client = httpx.Client(
            base_url=self.base_url or None,
            timeout=self.timeout or 10.0,
            verify=self.verify if self.verify is not None else True,
            headers=self.headers,
            event_hooks=event_hooks
        )

    def close(self) -> None:
        self.client.close()

    def request(self, req: Dict[str, Any]) -> Dict[str, Any]:
        method = req.get("method", "GET")
        path = req.get("path", "")
        # Ensure path is not None or empty when no base_url
        if not path:
            path = "/"
        params = req.get("params")
        headers = req.get("headers") or {}
        # 'body' holds JSON object or raw content from test step
        json_data = req.get("body")
        data = req.get("data")
        files = req.get("files")
        timeout = req.get("timeout", self.timeout)
        verify = req.get("verify", self.verify)
        allow_redirects = req.get("allow_redirects", True)
        auth = req.get("auth")

        # auth support: basic, bearer
        if auth and isinstance(auth, dict):
            if auth.get("type") == "basic":
                username = auth.get("username", "")
                password = auth.get("password", "")
                auth_tuple = (username, password)
            elif auth.get("type") == "bearer":
                token = auth.get("token", "")
                headers = {**headers, "Authorization": f"Bearer {token}"}
                auth_tuple = None
            else:
                auth_tuple = None
        else:
            auth_tuple = None

        resp = self.client.request(
            method=method,
            url=path,
            params=params,
            headers=headers,
            json=json_data,
            data=data,
            files=files,
            timeout=timeout,
            follow_redirects=bool(allow_redirects),
            auth=auth_tuple,
        )

        body_text: Optional[str] = None
        body_json: Any = None
        try:
            body_json = resp.json()
        except Exception:
            try:
                body_text = resp.text
            except Exception:
                body_text = None

        result = {
            "status_code": resp.status_code,
            "headers": dict(resp.headers),
            "body": body_json if body_json is not None else body_text,
            "elapsed_ms": resp.elapsed.total_seconds() * 1000.0 if resp.elapsed else None,
            "url": str(resp.request.url),
            "method": str(resp.request.method),
        }
        
        # 如果启用了 http_stat，添加时间统计
        if self.enable_http_stat and self.timing_collector:
            httpstat = self.timing_collector.build_httpstat(resp)
            result["httpstat"] = httpstat.to_dict()
        
        return result

==> drun-2.1.0.tar.gz: drun-2.1.0/drun/engine/http.py <==
from __future__ import annotations

from typing import Any, Dict, Optional
import httpx


class HTTPClient:
    def __init__(self, base_url: Optional[str] = None, timeout: Optional[float] = None, verify: Optional[bool] = None, headers: Optional[Dict[str, str]] = None) -> None:
        self.base_url = base_url or ""
        self.timeout = timeout
        self.verify = verify
        self.headers = headers or {}
        event_hooks: Dict[str, list] = {}
        # httpstat 功能已移除，保留空 hooks

        self.client = httpx.Client(
            base_url=self.base_url or None,
            timeout=self.timeout or 10.0,
            verify=self.verify if self.verify is not None else True,
            headers=self.headers,
            event_hooks=event_hooks
        )

    def close(self) -> None:
        self.client.close()

    def request(self, req: Dict[str, Any]) -> Dict[str, Any]:
        method = req.get("method", "GET")
        path = req.get("path", "")
        # Ensure path is not None or empty when no base_url
        if not path:
            path = "/"
        params = req.get("params")
        headers = req.get("headers") or {}
        # 'body' holds JSON object or raw content from test step
        json_data = req.get("body")
        data = req.get("data")
        files = req.get("files")
        timeout = req.get("timeout", self.timeout)
        verify = req.get("verify", self.verify)
        allow_redirects = req.get("allow_redirects", True)
        auth = req.get("auth")

        # auth support: basic, bearer
        if auth and isinstance(auth, dict):
            if auth.get("type") == "basic":
                username = auth.get("username", "")
                password = auth.get("password", "")
                auth_tuple = (username, password)
            elif auth.get("type") == "bearer":
                token = auth.get("token", "")
                headers = {**headers, "Authorization": f"Bearer {token}"}
                auth_tuple = None
            else:
                auth_tuple = None
        else:
            auth_tuple = None

        resp = self.client.request(
            method=method,
            url=path,
            params=params,
            headers=headers,
            json=json_data,
            data=data,
            files=files,
            timeout=timeout,
            follow_redirects=bool(allow_redirects),
            auth=auth_tuple,
        )

        body_text: Optional[str] = None
        body_json: Any = None
        try:
            body_json = resp.json()
        except Exception:
            try:
                body_text = resp.text
            except Exception:
                body_text = None

        result = {
            "status_code": resp.status_code,
            "headers": dict(resp.headers),
            "body": body_json if body_json is not None else body_text,
            "elapsed_ms": resp.elapsed.total_seconds() * 1000.0 if resp.elapsed else None,
            "url": str(resp.request.url),
            "method": str(resp.request.method),
        }
        return result
